@@ -1,6 +1,6 @@
 /*
  *  cryptmount - a utility for user-level mounting of encrypted filesystems
- *  (C)Copyright 2005-2017, RW Penney
+ *  (C)Copyright 2005-2018, RW Penney
  */
 
 /*
@@ -162,9 +162,9 @@ int fs_test_blkgetsz()
     const char *devices[] = {
         "/dev/hda", "/dev/hda1", "/dev/hda2", "/dev/hda3",
         "/dev/hdb", "/dev/hdb1", "/dev/hdb2", "/dev/hdb3",
-        "/dev/hdc", "/dev/hdc1", "/dev/hdc2", "/dev/hdc3",
         "/dev/sda", "/dev/sda1", "/dev/sda2", "/dev/sda3",
         "/dev/sdb", "/dev/sdb1", "/dev/sdb2", "/dev/sdb3",
+        "/dev/xvda", "/dev/xvda1",
         "/dev/sr0", "/dev/sr1",
         NULL };
 #endif
@@ -1579,5 +1579,5 @@ int main(int argc, char *argv[])
 }
 
 /*
- *  (C)Copyright 2005-2017, RW Penney
+ *  (C)Copyright 2005-2018, RW Penney
  */
